(function ($) {
  function showButton() {
    if (
      document
        .getElementById('zendeskloader')
        .contentWindow.document.getElementsByTagName('button').length > 0
    ) {
      var iframe = document.getElementById('zendeskloader');
      iframe.style.bottom = 0;
      iframe.style.opacity = 1;
    }
  }

  function hideButton() {
    var iframe = document.getElementById('zendeskloader');
    iframe.style.bottom = '-' + iframe.style.height;
    iframe.style.opacity = 0;
  }

  function loadZendeskChat(callback) {
    var zdscript = document.createElement('script');
    zdscript.setAttribute('id', 'ze-snippet');
    zdscript.src =
      'https://static.zdassets.com/ekr/snippet.js?key=' +
      drupalSettings.zendeskloader.key;
    document.getElementsByTagName('body')[0].appendChild(zdscript);

    window.zdonload = setInterval(
      function () {
        if (typeof zE !== 'undefined' && typeof zE.activate !== 'undefined') {
          clearInterval(window.zdonload);

          // hide their button, we're using ours
          $zopim(function () {
            $zopim.livechat.hideAll();
          });

          // add observer on the main widget
          var widget = document.getElementById('webWidget');
          var observer = new MutationObserver(function () {
            if (widget.style.visibility == 'hidden') {
              showButton();
            } else {
              hideButton();
            }
          });
          observer.observe(widget, { attributes: true });

          callback();
        }
      },
      50,
      null
    );
  }

  window.loadAndOpenZendeskChat = function () {
    // if already loaded, just activate
    if (typeof zE !== 'undefined' && typeof zE.activate !== 'undefined') {
      zE.activate();
    } else {
      // load in the Zendesk JS
      loadZendeskChat(function () {
        localStorage.setItem('zendeskloader_hasOpened', true);

        window.setTimeout(function () {
          zE.activate();
        }, 1000);
      });
    }
  };

  // set up the button when its found in the DOM
  function setupButton() {
    // set up a timeout, if the button isn't ready within a second try and create it again
    // for some reason in Firefox it sometimes doesn't add it
    window.zdWatch = setTimeout(function() {
      clearInterval(window.zdSetup);
      createButton();
    }, 1000);

    window.zdSetup = setInterval(function () {
      if (
        document
          .getElementById('zendeskloader')
          .contentWindow.document.getElementsByTagName('button').length > 0
      ) {
        clearTimeout(window.zdWatch);
        clearInterval(window.zdSetup);

        document
          .getElementById('zendeskloader')
          .contentWindow.document.getElementsByTagName('button')[0]
          .addEventListener('click', function () {
            loadAndOpenZendeskChat();
          });

        showButton();
      }
    }, 50);
  }

  // add the button in the iframe
  function createButton() {
    window.zdButton = setInterval(function () {
      if (document.getElementById('zendeskloader')) {
        clearInterval(window.zdButton);

        document.getElementById(
          'zendeskloader'
        ).contentWindow.document.documentElement.innerHTML =
          drupalSettings.zendeskloader.content;

        setupButton();
      }
    }, 50);
  }

    // set up our own iframe for the ZD button
  function createContainer() {
    var iframe = new DOMParser()
      .parseFromString(drupalSettings.zendeskloader.container, 'text/html')
      .getElementById('zendeskloader');
    iframe.style.bottom = '-' + iframe.style.height;
    iframe.style.opacity = 0;
    document.getElementsByTagName('body')[0].appendChild(iframe);

    createButton();
  }

  Drupal.behaviors.zendesk_loader = {
    attach: function (context) {
      // start loading the ZenDesk JS is the widget has already been opened
      if (localStorage.getItem('zendeskloader_hasOpened')) {
        loadZendeskChat(function () {
          createContainer();
        });
      } else {
        createContainer();
      }
    },
  };
})();
